/**
 * GNU Lesser General Public License
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation,
 * version 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 *
 * Company:      DFKI GmbH<p>
 * @author Andreas Lauer
 * @version 1.0
 */

package dfki.frodo.tools.rdf_schema_grapher;

import java.util.Collection;
import java.util.LinkedList;

import org.w3c.rdf.model.Statement;


public abstract class AbstractEdgeExtractor implements EdgeExtractor
{
    public static class StatementInfo implements EdgeExtractor.StatementInfo
    {
        StatementInfo()
        {
            mHasBeenConsidered = false;
            mHasBeenRejected = false;
            mStatement = null;
        }

        public void hasBeenConsidered( boolean thatsTrue ) { mHasBeenConsidered = thatsTrue; }
        public boolean hasBeenConsidered() { return( mHasBeenConsidered ); }

        //statement was not processable
        public void hasBeenRejected( boolean thatsTrue ) { mHasBeenRejected = thatsTrue; }
        public boolean hasBeenRejected() { return( mHasBeenRejected ); }

        public void setStatement( Statement s ) { mStatement = s; }
        public Statement getStatement() { return( mStatement ); }

        private Statement mStatement;
        private boolean mHasBeenConsidered;
        private boolean mHasBeenRejected;
    }

    public static class ProcessingInfo implements EdgeExtractor.ProcessingInfo
    {
        ProcessingInfo()
        {
            mStatementInfos = new LinkedList();
        }

        public Collection getStatementInfos()
        {
            return( mStatementInfos );
        }

        public void addStatementInfo( EdgeExtractor.StatementInfo info )
        {
            mStatementInfos.add( info );
        }

        private Collection/*TripleInfo*/ mStatementInfos;
    }


    public EdgeExtractor.StatementInfo createStatementInfoFor( Statement s )
    {
        StatementInfo info = new StatementInfo();
        info.setStatement( s );
        return( info );
    }

    public EdgeExtractor.ProcessingInfo createNewProcessingInformation()
    {
        return( new ProcessingInfo() );
    }

}