/**
 * GNU Lesser General Public License
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation,
 * version 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 *
 * Company:      DFKI GmbH<p>
 * @author Andreas Lauer
 * @version 1.0
 */

package dfki.frodo.tools.rdf_schema_grapher;

import java.io.Writer;
import java.io.IOException;

import java.util.Collection;

import org.w3c.rdf.model.Statement;
import org.w3c.rdf.model.ModelException;

import dfki.util.config.Config;


public interface EdgeExtractor
{
    /**
     * Information collected on the latest extraction run.
     * It can be used to promt additional information to the user
     * of the visualization tool.
     */
    public interface ProcessingInfo
    {
        //Information triple processing
        Collection/*StatementInfo*/ getStatementInfos();
        void addStatementInfo( StatementInfo info );

        //more to come
        // - pruned nodes
        // - #extracted edges
        // - #extracted nodes
    }

    public interface StatementInfo
    {
        //the statement has been considered in the extraction
        void hasBeenConsidered( boolean thatsTrue );
        boolean hasBeenConsidered();

        //statement was not processable
        void hasBeenRejected( boolean thatsTrue );
        boolean hasBeenRejected();

        void setStatement( Statement s );
        Statement getStatement();
    }


    //leave the creation control to the implementing class
    StatementInfo createStatementInfoFor( Statement s );

    void extractAllEdges( Config config ) throws ModelException;

    void printResultTo( Writer w ) throws IOException;

    ProcessingInfo createNewProcessingInformation();
    ProcessingInfo getProcessingInformation();
}
