/**
 * GNU Lesser General Public License
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation,
 * version 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 *
 * Copyright:    Copyright (c) DFKI GmbH<p>
 * Company:      DFKI GmbH<p>
 * @author Andreas Lauer
 * @version 1.0
 */

package dfki.frodo.tools.rdf_schema_grapher;

import java.util.ArrayList;
import java.util.List;


public class QueryCache
{
    public static class Entry implements Comparable
    {
        Entry( String id )
        {
            this( id, -1, null, null, null );
        }

        Entry( String id, int code, String rdfsFn, String picURL, String dotURL )
        {
            mId = id;
            mCode = code;
            mRDFSFileName = rdfsFn;
            mPictureURL = picURL;
            mDotURL = dotURL;
        }

        public int compareTo( Object other )
        {
            return( mId.compareTo( ((Entry)other).getId() ) );
        }

        public boolean equals( Object other )
        {
            if (!(other instanceof Entry))
               return( false );
            return( getId().equals( ((Entry)other).getId() ) );
        }

        public String getId() { return( mId ); }
        public int getCode() { return( mCode ); }
        public String getPictureURL() { return( mPictureURL ); }
        public void setPictureURL( String url ) { mPictureURL = url; }
        public String getDotURL() { return( mDotURL ); }
        public void setDotURL( String url ) { mDotURL = url; }

        private String mId;
        private int mCode;
        private String mRDFSFileName;
        private String mPictureURL;
        private String mDotURL;
    }

    //wird mal ein LRUCache
    public QueryCache()
    {
        mEntryIdCounter = 0;
        mEntries = new ArrayList();
    }

    synchronized public boolean isCached( String id )
    {
        return( mEntries.contains( new Entry( id ) ) );
    }

    synchronized public Entry getEntry( String id )
    {
        int i = mEntries.indexOf( new Entry( id ) );
        if (i == -1)
           return( null );
        return( (Entry)mEntries.get( i ) );
    }

    synchronized public void addEntry( Entry e )
    {
        int i = mEntries.indexOf( e );
        if (i != -1)
           mEntries.remove( i );
        mEntries.add( e );
    }

    synchronized public Entry createNewEntry( String id )
    {
        return( new Entry( id, mEntryIdCounter++, null, null, null ) );
    }

    private static int mEntryIdCounter;
    private List mEntries;
}