/**
 * GNU Lesser General Public License
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation,
 * version 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 *
 * Company:      DFKI GmbH<p>
 * @author Andreas Lauer
 * @version 1.0
 */

package dfki.frodo.tools.rdf_schema_grapher;

import java.io.Writer;
import java.io.IOException;

import java.util.Collection;
import java.util.Iterator;

import org.w3c.rdf.model.*;
import org.w3c.rdf.util.RDFUtil;
import org.w3c.rdf.vocabulary.rdf_syntax_19990222.*;
import org.w3c.rdf.vocabulary.rdf_schema_19990303.RDFS;

import dfki.util.config.Config;

public class SimpleEdgeExtractor extends AbstractEdgeExtractor
{
    public SimpleEdgeExtractor( ModelProcessor p, GraphBuilder b )
    {
        mModelProcessor = p;
        mGraphBuilder = b;
    }

    public void extractAllEdges( Config config )
    {
        mGraphBuilder.start( config );

        //alle Statements durchlaufen
        Collection statements = mModelProcessor.allStatements();
        Iterator i = statements.iterator();
        while( i.hasNext() )
        {
            Statement stmt = (Statement)i.next();
            try
            {
                //alle Statements mit Praedikat 'instanceOf' als Kante in den Graphen
                Resource predicate = stmt.predicate();
                if (!predicate.getURI().equals( RDFS.subClassOf.getURI() ))
                {
                    continue;
                }

                RDFNode object = stmt.object();
                Resource subject = stmt.subject();
                mGraphBuilder.setEdge( mModelProcessor.getAbbreviatedURI( object.getLabel() ),
                                       mModelProcessor.getAbbreviatedURI( subject.getURI() ) );

            }
            catch( ModelException e )
            {
                e.printStackTrace( System.out );
            }
        }
    }

    public void printResultTo( Writer w ) throws IOException
    {
        mGraphBuilder.printGraphTo( w );
    }

    public EdgeExtractor.ProcessingInfo getProcessingInformation()
    {
        return null;
    }

    private ModelProcessor mModelProcessor;
    private GraphBuilder mGraphBuilder;
}