/**
 * GNU Lesser General Public License
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation,
 * version 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 *
 * Company:      DFKI GmbH<p>
 * @author Andreas Lauer
 * @version 1.0
 */

package dfki.util;

/**
 * Additional string operations.
 */
public class Strings
{
    /**
     * Replaces a string pattern.
     * @param str The string to work on.
     * @param oldPattern The string to replace.
     * @param replaceWith The new string.
     */
    public static String replace( final String str, final String oldPattern, final String replaceWith )
    {
        return( replace( str, oldPattern, replaceWith, 0 ) );
    }

    public static String replace( final String str, final String oldPattern, final String replaceWith, int startPos )
    {
        String result = str;

        if (oldPattern == null || replaceWith == null || str == null)
         return( result );

        int index = str.indexOf( oldPattern, startPos );
        if (index == -1)
           return( result );

        result = str.substring( 0, index ) + replaceWith;
        if (index+oldPattern.length() < str.length())
        {
            result += str.substring( index+oldPattern.length() );
        }

        return( result );
    }


    public static String from( final Object[] o )
    {
        if (o == null)
           return( "null" );

        String str = null;
        str = "[";
        String[] arg = (String[])o;
        for( int i=0; i<arg.length; ++i )
        {
            if (i != 0)
                str += ", ";
            str += arg[i];
        }
        str += "]";

        return( str );
    }
}