/**
 * GNU Lesser General Public License
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation,
 * version 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 *
 * Company:      DFKI GmbH<p>
 * @author Andreas Lauer
 * @version 1.0
 */

package dfki.util;

import dfki.util.debug.Debug;

import dfki.util.config.Config;
import dfki.util.config.JavaPropertyReader;

public class Util
{
    public final static String MODULE_NAME = "Util";

    /**
     * Base class for properties defined in the <code>dfki.util.*</code> packages.
     * Property identifiers start with <code>Util.</code>.
     */
    public static class Property extends dfki.util.config.Config.Property
    {
        protected Property( String path, String descr )
        {
            super( MODULE_NAME + Config.Property.SEPARATOR + path, descr );
        }
    }

    private static Debug mDebug = null;
    //private static Config mConfig = null;
    static
    {
        //mConfig = new Config( System.getProperties() );
        mDebug = Debug.forModule( MODULE_NAME );
    }

    public static Debug debug()
    {
        return( mDebug );
    }


    public static Config config()
    {
        return( Config.cfg() );
    }


    /** Empty, private contructor to avoid instantiation */
    private Util()
    {
    }
}