/**
 * GNU Lesser General Public License
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation,
 * version 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 *
 * Company:      DFKI GmbH<p>
 * @author Andreas Lauer
 * @version 1.0
 */

package dfki.util.config;

import java.util.Map;

/**
 * Abstract class for reading property settings.
 * Look at the direct subclasses of <code>ConfigReader</code> for
 * currently available readers.
 */
public abstract class ConfigReader
{
    /**
     * Exception denoting errors while reading property settings.
     */
    public static class Exception extends java.lang.Exception
    {
        public Exception( String msg ) { super( msg ); }
    }

    /**
     * Reads the property settings into a map.
     * Values of a property can either be of type <code>String</code>
     * or <code>String[]</code> (in case of a multivalued property).
     * @throws ConfigReader.Exception Denoting a failure while generating
     *                 the property value map.
     * @see Config.Property
     */
    public abstract Map/*String,String|String[]*/ readPropertySettings()
       throws ConfigReader.Exception;
}