/**
 * GNU Lesser General Public License
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation,
 * version 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 *
 * Company:      DFKI GmbH<p>
 * @author Andreas Lauer
 * @version 1.0
 */

package dfki.util.config;

import java.util.Map;
import java.util.TreeMap;
import java.util.Iterator;
import java.util.Enumeration;

import javax.servlet.ServletConfig;

/**
 * Reads property settings out of a <code>ServletConfig</code>
 * object.
 */
public class ServletInitParameterReader extends ConfigReader
{
    public ServletInitParameterReader( ServletConfig servletConfig )
    {
        if (servletConfig == null)
           throw( new NullPointerException( "no servlet config" ) );

        mServletConfig = servletConfig;
    }

    public Map/*String,String*/ readPropertySettings()
        throws ConfigReader.Exception
    {
        Map settings = new TreeMap();
        Enumeration e = mServletConfig.getInitParameterNames();
        while( e.hasMoreElements() )
        {
            String parameter = (String)e.nextElement();
            String value = mServletConfig.getInitParameter( parameter );
            settings.put( parameter, value );
        }
        return( settings );
    }

    private ServletConfig mServletConfig;
}