/**
 * GNU Lesser General Public License
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation,
 * version 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 *
 * Company:      DFKI GmbH<p>
 * @author Andreas Lauer
 * @version 1.0
 */

package dfki.util.config;

import java.util.Map;
import java.util.TreeMap;
import java.util.Iterator;
import java.util.Enumeration;

import javax.servlet.ServletRequest;

/**
 * Reads property settings out of a <code>ServletRequest</code> object.
 */
public class ServletRequestReader extends ConfigReader
{
    public ServletRequestReader( ServletRequest request )
    {
        if (request == null)
           throw( new NullPointerException( "no servlet request" ) );

        mServletRequest = request;
    }

    public Map/*String,String|String[]*/ readPropertySettings()
        throws ConfigReader.Exception
    {
        Map settings = new TreeMap();
        Enumeration e = mServletRequest.getParameterNames();
        while( e.hasMoreElements() )
        {
            String parameter = (String)e.nextElement();
            settings.put( parameter, mServletRequest.getParameter( parameter ) );
            /*
            String[] values = mServletRequest.getParameterValues( parameter );
            if (values.length == 1)
            {
                settings.put( parameter, values[0] );
            }
            else
            {
                settings.put( parameter, values );
            }
            */
        }
        return( settings );
    }

    private ServletRequest mServletRequest;
}