/**
 * GNU Lesser General Public License
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation,
 * version 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 *
 * Company:      DFKI GmbH<p>
 * @author Andreas Lauer
 * @version 1.0
 */

package dfki.util.html;

public class HTML
{
    public static final String escape( String s )
    {
        StringBuffer sb = new StringBuffer();
        int n = s.length();
        for (int i = 0; i < n; i++)
        {
           char c = s.charAt(i);
           switch (c)
           {
              case '<': sb.append("&lt;"); break;
              case '>': sb.append("&gt;"); break;
              case '&': sb.append("&amp;"); break;
              case '"': sb.append("&quot;"); break;
              case '': sb.append("&agrave;");break;
              case '': sb.append("&Agrave;");break;
              case '': sb.append("&acirc;");break;
              case '': sb.append("&auml;");break;
              case '': sb.append("&auml;");break;
              case '': sb.append("&Acirc;");break;
              case '': sb.append("&aring;");break;
              case '': sb.append("&Aring;");break;
              case '': sb.append("&aelig;");break;
              case '': sb.append("&AElig;");break;
              case '': sb.append("&ccedil;");break;
              case '': sb.append("&Ccedil;");break;
              case '': sb.append("&eacute;");break;
              case '': sb.append("&Eacute;");break;
              case '': sb.append("&egrave;");break;
              case '': sb.append("&Egrave;");break;
              case '': sb.append("&ecirc;");break;
              case '': sb.append("&Ecirc;");break;
              case '': sb.append("&euml;");break;
              case '': sb.append("&Euml;");break;
              case '': sb.append("&iuml;");break;
              case '': sb.append("&Iuml;");break;
              case '': sb.append("&ocirc;");break;
              case '': sb.append("&Ocirc;");break;
              case '': sb.append("&ouml;");break;
              case '': sb.append("&Ouml;");break;
              case '': sb.append("&oslash;");break;
              case '': sb.append("&Oslash;");break;
              case '': sb.append("&szlig;");break;
              case '': sb.append("&ugrave;");break;
              case '': sb.append("&Ugrave;");break;
              case '': sb.append("&ucirc;");break;
              case '': sb.append("&Ucirc;");break;
              case '': sb.append("&uuml;");break;
              case '': sb.append("&Uuml;");break;
              case '': sb.append("&reg;");break;
              case '': sb.append("&copy;");break;
              case '': sb.append("&euro;"); break;
              // be carefull with this one (non-breaking whitee space)
              case ' ': sb.append("&nbsp;");break;

              default:  sb.append(c); break;
           }
        }
        return( sb.toString() );
     }

     private final static String[][] ESCAPES =
      {{  "&lt;"     , "<" } ,
       {  "&gt;"     , ">" } ,
       {  "&amp;"    , "&" } ,
       {  "&quot;"   , "\"" } ,
       {  "&agrave;" , "" } ,
       {  "&Agrave;" , "" } ,
       {  "&acirc;"  , "" } ,
       {  "&auml;"   , "" } ,
       {  "&Auml;"   , "" } ,
       {  "&Acirc;"  , "" } ,
       {  "&aring;"  , "" } ,
       {  "&Aring;"  , "" } ,
       {  "&aelig;"  , "" } ,
       {  "&AElig;"  , "" } ,
       {  "&ccedil;" , "" } ,
       {  "&Ccedil;" , "" } ,
       {  "&eacute;" , "" } ,
       {  "&Eacute;" , "" } ,
       {  "&egrave;" , "" } ,
       {  "&Egrave;" , "" } ,
       {  "&ecirc;"  , "" } ,
       {  "&Ecirc;"  , "" } ,
       {  "&euml;"   , "" } ,
       {  "&Euml;"   , "" } ,
       {  "&iuml;"   , "" } ,
       {  "&Iuml;"   , "" } ,
       {  "&ocirc;"  , "" } ,
       {  "&Ocirc;"  , "" } ,
       {  "&ouml;"   , "" } ,
       {  "&Ouml;"   , "" } ,
       {  "&oslash;" , "" } ,
       {  "&Oslash;" , "" } ,
       {  "&szlig;"  , "" } ,
       {  "&ugrave;" , "" } ,
       {  "&Ugrave;" , "" } ,
       {  "&ucirc;"  , "" } ,
       {  "&Ucirc;"  , "" } ,
       {  "&uuml;"   , "" } ,
       {  "&Uuml;"   , "" } ,
       {  "&nbsp;"   , " " } ,
       {  "&reg;"    , "\u00a9" } ,
       {  "&copy;"   , "\u00ae" } ,
       {  "&euro;"   , "\u20a0" } };


    public static final String unescape( String s )
    {
      int i, j, k, l ;

      i = s.indexOf("&");
      if (i > -1)
      {
         j = s.indexOf(";");
         if (j > i)
         {
            // ok this is not most optimized way to
            // do it, a StringBuffer would be better,
            // this is left as an exercise to the reader!
            String temp = s.substring(i , j + 1);
            // search in escape[][] if temp is there
            k = 0;
            while (k < ESCAPES.length)
            {
                if (ESCAPES[k][0].equals(temp)) break;
                else k++;
            }
            if (k < ESCAPES.length)
            {
                s = s.substring(0 , i) + ESCAPES[k][1] + s.substring(j + 1);
                return( unescape(s) ); // recursive call
              }
            }
         }
         return( s );
    }
}