/**
 * GNU Lesser General Public License
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation,
 * version 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 *
 * Company:      DFKI GmbH<p>
 * @author Andreas Lauer
 * @version 1.0
 */

package dfki.util.rdfs;

import java.util.Map;
import java.util.TreeMap;


public class RDFS
{
    public final static String DEFAULT_NAMESPACE = "http://www.w3.org/TR/1999/PR-rdf-schema-19990303#";


    public static class URIs
    {
        private URIs( String namespace )
        {
            mNamespace = namespace;
            mContainer = createURI( "Container" );
            mConstraintResource = createURI( "ConstraintResource");
            mLiteral = createURI( "Literal");
            mDomain = createURI( "domain");
            mRange = createURI( "range");
            mSeeAlso = createURI( "seeAlso");
            mProperty = createURI( "Property");
            mIsDefinedBy = createURI( "isDefinedBy");
            mLabel = createURI( "label" );
            mSubPropertyOf = createURI( "subPropertyOf" );
            mContainerMembershipProperty = createURI( "ContainerMembershipProperty" );
            mSubClassOf = createURI( "subClassOf" );
            mComment = createURI( "comment" );
            mConstraintProperty = createURI( "ConstraintProperty" );
            mClass = createURI( "Class" );
            mResource = createURI( "Resource" );
        }

        public String namespace() { return( mNamespace ); }
        public String literal() { return( mLiteral ); }
        public String domain() { return( mDomain ); }
        public String range() { return( mRange ); }
        public String subClassOf() { return( mSubClassOf ); }
        public String _class() { return( mClass ); }


        private String createURI( String name ) { return( mNamespace + name ); }

        private String mNamespace;
        private String mContainer, mConstraintResource, mLiteral, mDomain, mRange,
                       mSeeAlso, mProperty, mIsDefinedBy, mLabel, mSubPropertyOf,
                       mContainerMembershipProperty, mSubClassOf, mComment,
                       mConstraintProperty, mClass, mResource;
    }


    public static URIs getURIs()
    {
        return( getURIs( DEFAULT_NAMESPACE ) );
    }

    public static URIs getURIs( String namespace )
    {
        if (namespace == null)
           namespace = DEFAULT_NAMESPACE;
        URIs u = (URIs)mURIs.get( namespace );
        if (u == null)
        {
            u = new URIs( namespace );
            mURIs.put( namespace, u );
        }
        return( u );
    }


    private static Map/*String,URIs*/ mURIs = new TreeMap();
}